==> je_load_density-0.0.34.tar.gz: je_load_density-0.0.34/README.md <==
## LoadDensity
> Locust Wrapper \
> Wrapper for Locust, simplifying complex Locust configurations. \
> Solves problems:
>> * Checking Requests & Response for each load test
>> * Load testing for SOAP protocols
>> * Comparison of numerical values for each load test
>> * Detailed load test reports for each test.
---
### Features

>* HTTP HTTPS stress testing and load testing
>* Action FIle
>* response compare
>* CLI with action file

---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b3f05488c16a44959cbf0ec28d4c977c)](https://www.codacy.com/gh/JE-Chen/LoadDensity/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/LoadDensity&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/JE-Chen/LoadDensity/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/JE-Chen/LoadDensity/tree/main)

[![LoadDensity GitHub Actions Dev](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml)

[![LoadDensity GitHub Actions Stable](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/loaddensity/badge/?version=latest)](https://loaddensity.readthedocs.io/en/latest/?badge=latest)

https://loaddensity.readthedocs.io/en/latest/
---

## install

```
pip install je_locust_wrapper
```

## require

```
python 3.7 or later  
```

>* Test on
>>    * windows 10 ~ 11
>>    * osx 10.5 ~ 11 big sur
>>    * ubuntu 20.0.4
>>    * raspberry pi 3B+
>>    * All test in test dir

==> je_load_density-0.0.44.tar.gz: je_load_density-0.0.44/README.md <==
## LoadDensity
> Project Kanban \
> https://github.com/orgs/Integrated-Testing-Environment/projects/4 \
> Locust Wrapper \
> Wrapper for Locust, simplifying complex Locust configurations. \
> Solves problems:
>> * Checking Requests & Response for each load test
>> * Load testing for SOAP protocols
>> * Comparison of numerical values for each load test
>> * Detailed load test reports for each test.
---
### Features

>* HTTP HTTPS stress testing and load testing
>* Action FIle
>* response compare
>* CLI with action file

---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b3f05488c16a44959cbf0ec28d4c977c)](https://www.codacy.com/gh/JE-Chen/LoadDensity/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/LoadDensity&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/Integrated-Testing-Environment/LoadDensity/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/Integrated-Testing-Environment/LoadDensity/tree/main)

[![LoadDensity GitHub Actions Dev](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml)

[![LoadDensity GitHub Actions Stable](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/loaddensity/badge/?version=latest)](https://loaddensity.readthedocs.io/en/latest/?badge=latest)

https://loaddensity.readthedocs.io/en/latest/
---

## install

```
pip install je_locust_wrapper
```

## require

```
python 3.7 or later  
```

>* Test on
>>    * windows 10 ~ 11
>>    * osx 10.5 ~ 11 big sur
>>    * ubuntu 20.0.4
>>    * raspberry pi 3B+
>>    * All test in test dir
>>    * 
### Architecture Diagram
![Architecture Diagram](architecture_diagram/LoadDnesity_Archirecture.drawio.png)
